@@ -1,11 +1,13 @@
-from ode_solver import ODESolver
-import rooted_trees as rt
+from __future__ import absolute_import
+from nodepy.ode_solver import ODESolver
+import nodepy.rooted_trees as rt
+from six.moves import range
 
 #=====================================================
 class GeneralLinearMethod(ODESolver):
 #=====================================================
     """ General class for multstage, multistep methods.
-    
+
         This is a pure virtual class; only its child classes
         should be instantiated.
     """
@@ -14,11 +16,11 @@ class GeneralLinearMethod(ODESolver):
 
     def order_conditions(self,p):
         """
-        Generate a list of order conditions up to order p 
+        Generate a list of order conditions up to order p
         """
 
-        forest=rt.recursive_trees(0)
-        for i in range(1,p+1): forest+=rt.recursive_trees(i)
+        forest=rt.list_trees(0)
+        for i in range(1,p+1): forest+=rt.list_trees(i)
         oc={rt.RootedTree(''):''}
         for tree in forest[1:]:
             oc[tree]=self.elementary_weight(tree)-rt.Emap(tree)
