@@ -46,7 +46,7 @@ At the moment, the following classes are implemented:
     >>> myrk = lsrk.load_low_storage('DDAS47')
     >>> print(myrk)
     DDAS4()7[2R]
-    2R Method of Tselios \& Simos (2007)
+    2R Method of Tselios & Simos (2007)
      0.000 |
      0.336 | 0.336
      0.286 | 0.094  0.192
@@ -83,20 +83,20 @@ from six.moves import range
 #=====================================================
 class TwoNRungeKuttaMethod(ExplicitRungeKuttaMethod):
 #=====================================================
-    """ Class for 2N low-storage Runge-Kutta methods.
+    r""" Class for 2N low-storage Runge-Kutta methods.
 
         These were developed by Williamson, and Carpenter & Kennedy.
 
-        References:
+        **References**:
             * :cite:`ketcheson2010`
 
-        Examples::
+        **Examples**
 
             >>> from nodepy import lsrk
             >>> erk = lsrk.load_low_storage("RK45[2N]")
             >>> print(erk)
             RK45[2N]
-            2N Method of Carpenter \& Kennedy (1994)
+            2N Method of Carpenter & Kennedy (1994)
              0     |
              0.150 | 0.150
              0.370 |-0.009  0.379
@@ -161,7 +161,7 @@ class TwoRRungeKuttaMethod(ExplicitRungeKuttaMethod):
         These were developed by van der Houwen, Wray, and Kennedy et al.
         Only 2R and 3R methods have been implemented so far.
 
-        References:
+        **References**:
             * :cite:`kennedy2000`
             * :cite:`ketcheson2010`
     """
@@ -239,7 +239,7 @@ class TwoRRungeKuttaPair(ExplicitRungeKuttaPair):
         These were developed by van der Houwen, Wray, and Kennedy et al.
         Only 2R and 3R methods have been implemented so far.
 
-        References:
+        **References**:
             * :cite:`kennedy2000`
             * :cite:`ketcheson2010`
     """
@@ -287,15 +287,15 @@ class TwoRRungeKuttaPair(ExplicitRungeKuttaPair):
             The implementation here is special for 2R/3R low-storage methods
             But it's not really ultra-low-storage yet.
 
-            INPUT:
-                f  -- function being integrated
-                t  -- array of previous solution times
-                u  -- array of previous solution steps
-                        (u[i,:] is the solution at time t[i])
-                dt -- length of time step to take
+            **Input**:
+                - f  -- function being integrated
+                - t  -- array of previous solution times
+                - u  -- array of previous solution steps
+                  (u[i,:] is the solution at time t[i])
+                - dt -- length of time step to take
 
-            OUTPUT:
-                unew -- approximate solution at time t[-1]+dt
+            **Output**:
+                - unew -- approximate solution at time t[-1]+dt
         """
         m=len(self); b=self.b; a=self.a
         S2=u[:]
@@ -339,7 +339,7 @@ class TwoRRungeKuttaPair(ExplicitRungeKuttaPair):
 #=====================================================
 class TwoSRungeKuttaMethod(ExplicitRungeKuttaMethod):
 #=====================================================
-    """
+    r"""
         Class for low-storage Runge-Kutta methods
         that use Ketcheson's assumption (2S, 2S*, and 3S* methods).
 
@@ -411,15 +411,15 @@ class TwoSRungeKuttaMethod(ExplicitRungeKuttaMethod):
             The implementation here is special for 2S/2S*/3S* low-storage methods,
             but it's not really ultra-low-storage yet.
 
-            INPUT:
-                f  -- function being integrated
-                t  -- array of previous solution times
-                u  -- array of previous solution steps
-                        (u[i,:] is the solution at time t[i])
-                dt -- length of time step to take
+            **Input**:
+                - f  -- function being integrated
+                - t  -- array of previous solution times
+                - u  -- array of previous solution steps
+                  (u[i,:] is the solution at time t[i])
+                - dt -- length of time step to take
 
-            OUTPUT:
-                unew -- approximate solution at time t[-1]+dt
+            **Output**:
+                - unew -- approximate solution at time t[-1]+dt
         """
         m=len(self)
         S1=u[-1]+0. # by adding zero we get a copy; is there a better way?
@@ -443,7 +443,7 @@ class TwoSRungeKuttaMethod(ExplicitRungeKuttaMethod):
 #=====================================================
 class TwoSRungeKuttaPair(ExplicitRungeKuttaPair):
 #=====================================================
-    """
+    r"""
         Class for low-storage embedded Runge-Kutta pairs
         that use Ketcheson's assumption (2S, 2S*, and 3S* methods).
 
@@ -561,16 +561,16 @@ class TwoSRungeKuttaPair(ExplicitRungeKuttaPair):
         """
             Take a time step on the ODE u'=f(t,u).
 
-            INPUT:
-                f  -- function being integrated
-                t  -- array of previous solution times
-                u  -- array of previous solution steps
-                        (u[i,:] is the solution at time t[i])
-                dt -- length of time step to take
+            **Input**:
+                - f  -- function being integrated
+                - t  -- array of previous solution times
+                - u  -- array of previous solution steps
+                  (u[i,:] is the solution at time t[i])
+                - dt -- length of time step to take
 
-            OUTPUT:
-                S1 -- approximate solution at time t[-1]+dt
-                S2 -- error estimate at time t[-1]+dt
+            **Output**:
+                - S1 -- approximate solution at time t[-1]+dt
+                - S2 -- error estimate at time t[-1]+dt
 
             The implementation here is special for 2S low-storage
             embedded pairs.
@@ -772,7 +772,7 @@ def load_low_storage(which='All'):
     #================================================
     fullname  = 'RK45[2N]'
     shortname = 'RK45[2N]'
-    description = '2N Method of Carpenter \& Kennedy (1994)'
+    description = '2N Method of Carpenter & Kennedy (1994)'
     coef_a = np.array([Rational(              0 ,              1 ),
                        Rational(  -567301805773 ,  1357537059087 ),
                        Rational( -2404267990393 ,  2016746695238 ),
@@ -787,7 +787,7 @@ def load_low_storage(which='All'):
     #================================================
     fullname  = 'DDAS4()7[2R]'
     shortname = 'DDAS47'
-    description = '2R Method of Tselios \& Simos (2007)'
+    description = '2R Method of Tselios & Simos (2007)'
     regs = 2
     b = np.array([0.0941840925477795334,
                   0.149683694803496998,
